import requests
from lxml import etree
import datetime


HISTORICAL='http://www.ecb.europa.eu/stats/eurofxref/eurofxref-hist.xml'
DAILY='http://www.ecb.europa.eu/stats/eurofxref/eurofxref-daily.xml'

def get_and_parse(data_url):
    result = requests.get(data_url)
    if result.status_code == requests.codes.ok:
        return parse_and_load(result.content)
        
def parse_and_load(content):
    data = []
    doc = etree.XML(content)
    nodes = doc.iterchildren()
    subject = nodes.next()
    sender = nodes.next()
    parent_cube = nodes.next()
    for daily_cube in parent_cube.iterchildren():
        time = daily_cube.attrib['time']
        for currency_cube in daily_cube.iterchildren():
            currency = currency_cube.attrib['currency']
            rate = currency_cube.attrib['rate']
            date = get_date(time)
            data.append((currency,date,rate))
    return data
                
def get_date(date_string):
    return datetime.datetime.strptime(date_string, "%Y-%m-%d").date()

def get_historical_data():
    return get_and_parse(HISTORICAL)

def get_daily_data():
    return get_and_parse(DAILY)



import requests
from lxml import etree
import datetime
import pandas

HISTORICAL='http://www.ecb.europa.eu/stats/eurofxref/eurofxref-hist.xml'
DAILY='http://www.ecb.europa.eu/stats/eurofxref/eurofxref-daily.xml'

def get_and_parse(data_url):
    result = requests.get(data_url)
    if result.status_code == requests.codes.ok:
        return parse_and_load(result.content)
        
def parse_and_load(content):
    data = []
    doc = etree.XML(content)
    nodes = doc.iterchildren()
    subject = nodes.next()
    sender = nodes.next()
    parent_cube = nodes.next()
    times,currencies = get_index_and_cols(parent_cube)
    df = pandas.DataFrame(index=times,columns=currencies)
    load_dataframe(df,parent_cube)
    return df
    

def load_dataframe(df,node):
    for daily_cube in node.iterchildren():
        time = daily_cube.attrib['time']
        for currency_cube in daily_cube.iterchildren():
            currency = currency_cube.attrib['currency']
            rate = currency_cube.attrib['rate']
            df.ix[time,currency] = rate

def get_index_and_cols(node):
    times = []
    currencies = []
    for daily_cube in node.iterchildren():
        time = daily_cube.attrib['time']
        times.append(time)
        for currency_cube in daily_cube.iterchildren():
            currency = currency_cube.attrib['currency']
            if currency not in currencies:
                currencies.append(currency)
    return (times,currencies)
                    
def get_date(date_string):
    return datetime.datetime.strptime(date_string, "%Y-%m-%d").date()

def get_historical_data_df():
    return get_and_parse(HISTORICAL)

def get_daily_data_df():
    return get_and_parse(DAILY)



#!/usr/bin/env python

from distutils.core import setup

setup(name='pyeurofx',
      version='0.2',
      description='Python module to get and parse daily and historical FX rates from ECB',
      long_description='Please visit https://github.com/supercoderz/pyeurofx for more details',
      author='Narahari Allamraju',
      author_email='anarahari@gmail.com',
      url='https://github.com/supercoderz/pyeurofx',
      packages=['eurofx'],
      requires=['lxml','requests','pandas'],
     )
